==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/UserSchemaPropertiesProfile.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserSchemaPropertiesProfileItem;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserSchemaPropertiesProfile
 */
@JsonPropertyOrder({ UserSchemaPropertiesProfile.JSON_PROPERTY_ALL_OF })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserSchemaPropertiesProfile implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALL_OF = "allOf";
    private List<UserSchemaPropertiesProfileItem> allOf = null;

    public UserSchemaPropertiesProfile() {
    }

    public UserSchemaPropertiesProfile allOf(List<UserSchemaPropertiesProfileItem> allOf) {

        this.allOf = allOf;
        return this;
    }

    public UserSchemaPropertiesProfile addallOfItem(UserSchemaPropertiesProfileItem allOfItem) {
        if (this.allOf == null) {
            this.allOf = new ArrayList<>();
        }
        this.allOf.add(allOfItem);
        return this;
    }

    /**
     * Get allOf
     *
     * @return allOf
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALL_OF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<UserSchemaPropertiesProfileItem> getAllOf() {
        return allOf;
    }

    @JsonProperty(JSON_PROPERTY_ALL_OF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllOf(List<UserSchemaPropertiesProfileItem> allOf) {
        this.allOf = allOf;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserSchemaPropertiesProfile userSchemaPropertiesProfile = (UserSchemaPropertiesProfile) o;
        return Objects.equals(this.allOf, userSchemaPropertiesProfile.allOf);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allOf);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserSchemaPropertiesProfile {\n");
        sb.append("    allOf: ").append(toIndentedString(allOf)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/UserSchemaPropertiesProfile.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserSchemaPropertiesProfileItem;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserSchemaPropertiesProfile
 */
@JsonPropertyOrder({ UserSchemaPropertiesProfile.JSON_PROPERTY_ALL_OF })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserSchemaPropertiesProfile implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALL_OF = "allOf";
    private List<UserSchemaPropertiesProfileItem> allOf = null;

    public UserSchemaPropertiesProfile() {
    }

    public UserSchemaPropertiesProfile allOf(List<UserSchemaPropertiesProfileItem> allOf) {

        this.allOf = allOf;
        return this;
    }

    public UserSchemaPropertiesProfile addallOfItem(UserSchemaPropertiesProfileItem allOfItem) {
        if (this.allOf == null) {
            this.allOf = new ArrayList<>();
        }
        this.allOf.add(allOfItem);
        return this;
    }

    /**
     * Get allOf
     *
     * @return allOf
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALL_OF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<UserSchemaPropertiesProfileItem> getAllOf() {
        return allOf;
    }

    @JsonProperty(JSON_PROPERTY_ALL_OF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllOf(List<UserSchemaPropertiesProfileItem> allOf) {
        this.allOf = allOf;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserSchemaPropertiesProfile userSchemaPropertiesProfile = (UserSchemaPropertiesProfile) o;
        return Objects.equals(this.allOf, userSchemaPropertiesProfile.allOf);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allOf);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserSchemaPropertiesProfile {\n");
        sb.append("    allOf: ").append(toIndentedString(allOf)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
